==> clutternomore-1.1.3%2B1.21.10-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/HotbarMixin.java <==
package dev.tazer.clutternomore.common.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import dev.tazer.clutternomore.ClutterNoMoreClient;
import net.minecraft.class_1661;
import net.minecraft.class_310;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_310.class)
public class HotbarMixin {
    //? if >1.21.8 {
    @WrapOperation(method = "handleKeybinds", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Inventory;setSelectedSlot(I)V"))
    private void pickBlock(class_1661 instance, int selectedIndex, Operation<Void> original) {
        if (ClutterNoMoreClient.OVERLAY != null) {
            int maxIndex = ClutterNoMoreClient.OVERLAY.shapes.size() - 1;
            if (selectedIndex < 0) selectedIndex = 0;
            if (selectedIndex > maxIndex) selectedIndex = maxIndex;
            ClutterNoMoreClient.OVERLAY.changeSlot(selectedIndex);
        } else {
            original.call(instance, selectedIndex);
        }
    }
     
    //?} else {
    /*@WrapOperation(method = "handleKeybinds", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/KeyMapping;consumeClick()Z", ordinal = 2))
    private boolean pickBlock(KeyMapping instance, Operation<Boolean> original, @Local int selectedIndex) {
        var b = original.call(instance);
        if (ClutterNoMoreClient.OVERLAY != null && b) {
            int maxIndex = ClutterNoMoreClient.OVERLAY.shapes.size() - 1;
            if (selectedIndex < 0) selectedIndex = 0;
            if (selectedIndex > maxIndex) selectedIndex = maxIndex;
            ClutterNoMoreClient.OVERLAY.changeSlot(selectedIndex);
            return false;
        }
        return b;
    }
    *///?}

}

==> clutternomore-1.1.6%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/HotbarMixin.java <==
package dev.tazer.clutternomore.common.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import dev.tazer.clutternomore.ClutterNoMoreClient;
import net.minecraft.class_304;
import net.minecraft.class_310;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_310.class)
public class HotbarMixin {
    //? if >1.21.8 {
    /*@WrapOperation(method = "handleKeybinds", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Inventory;setSelectedSlot(I)V"))
    private void pickBlock(Inventory instance, int selectedIndex, Operation<Void> original) {
        if (ClutterNoMoreClient.OVERLAY != null) {
            int maxIndex = ClutterNoMoreClient.OVERLAY.shapes.size() - 1;
            if (selectedIndex < 0) selectedIndex = 0;
            if (selectedIndex > maxIndex) selectedIndex = maxIndex;
            ClutterNoMoreClient.OVERLAY.changeSlot(selectedIndex);
        } else {
            original.call(instance, selectedIndex);
        }
    }
     
    *///?} else {
    @WrapOperation(method = "handleKeybinds", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/KeyMapping;consumeClick()Z", ordinal = 2))
    private boolean pickBlock(class_304 instance, Operation<Boolean> original, @Local int selectedIndex) {
        var b = original.call(instance);
        if (ClutterNoMoreClient.OVERLAY != null && b) {
            int maxIndex = ClutterNoMoreClient.OVERLAY.shapes.size() - 1;
            if (selectedIndex < 0) selectedIndex = 0;
            if (selectedIndex > maxIndex) selectedIndex = maxIndex;
            ClutterNoMoreClient.OVERLAY.changeSlot(selectedIndex);
            return false;
        }
        return b;
    }
    //?}

}
